@@ -63,11 +63,10 @@ from zope.traversing.browser import absoluteURL
 
 # import local packages
 from ztfy.jqueryui import jquery_multiselect, jquery_colorpicker
-from ztfy.security.browser import ztfy_security
 from ztfy.security.browser.roles import RolesEditForm
 from ztfy.skin.container import ContainerBaseView
 from ztfy.skin.form import DialogAddForm, EditForm, DialogEditForm
-from ztfy.skin.menu import MenuItem, JsMenuItem
+from ztfy.skin.menu import MenuItem, DialogMenuItem
 from ztfy.thesaurus.browser import ztfy_thesaurus
 from ztfy.thesaurus.loader.config import ThesaurusLoaderConfiguration, \
                                          ThesaurusUpdaterConfiguration, \
@@ -195,12 +194,6 @@ def ThesaurusAutomaticSelectWidgetFactory(field, request):
     return FieldWidget(field, ThesaurusAutomaticSelectWidget(request))
 
 
-class ThesaurusAddMenuItem(JsMenuItem):
-    """Thesaurus add menu item"""
-
-    title = _(":: Add thesaurus")
-
-
 class ThesaurusAddForm(DialogAddForm):
     """Thesaurus add form"""
 
@@ -236,6 +229,13 @@ class ThesaurusAddForm(DialogAddForm):
         locate(thesaurus, removeSecurityProxy(self.context), '++thesaurus++' + thesaurus.name)
 
 
+class ThesaurusAddMenuItem(DialogMenuItem):
+    """Thesaurus add menu item"""
+
+    title = _(":: Add thesaurus")
+    target = ThesaurusAddForm
+
+
 class ThesaurusEditForm(EditForm):
     """Thesaurus edit form"""
 
@@ -271,16 +271,6 @@ class ThesaurusEditForm(EditForm):
 # Thesaurus roles menus and forms
 #
 
-class ThesaurusRolesMenuItem(JsMenuItem):
-    """Thesaurus roles menu item"""
-
-    title = _(":: Roles...")
-
-    def render(self):
-        ztfy_security.need()
-        jquery_multiselect.need()
-        return super(ThesaurusRolesMenuItem, self).render()
-
 
 class ThesaurusRolesEditForm(RolesEditForm):
     """Thesaurus roles edit form"""
@@ -290,6 +280,13 @@ class ThesaurusRolesEditForm(RolesEditForm):
     parent_interface = IThesaurus
 
 
+class ThesaurusRolesMenuItem(DialogMenuItem):
+    """Thesaurus roles menu item"""
+
+    title = _(":: Roles...")
+    target = ThesaurusRolesEditForm
+
+
 #
 # Thesaurus extracts menus and forms
 #
@@ -378,7 +375,6 @@ class ThesaurusExtractsListView(ContainerBaseView):
     def render(self):
         jquery_colorpicker.need()
         jquery_multiselect.need()
-        ztfy_security.need()
         ztfy_thesaurus.need()
         return super(ThesaurusExtractsListView, self).render()
 
@@ -387,12 +383,6 @@ class ThesaurusExtractsListView(ContainerBaseView):
         return IThesaurusExtracts(self.context).values()
 
 
-class ThesaurusExtractAddFormMenuItem(JsMenuItem):
-    """Thesaurus extract add form menu item"""
-
-    title = _(":: Add extract...")
-
-
 class IThesaurusExtractAddInfo(Interface):
     """Extra info for thesaurus extract add form"""
 
@@ -442,6 +432,13 @@ class ThesaurusExtractAddForm(DialogAddForm):
         return result
 
 
+class ThesaurusExtractAddFormMenuItem(DialogMenuItem):
+    """Thesaurus extract add form menu item"""
+
+    title = _(":: Add extract...")
+    target = ThesaurusExtractAddForm
+
+
 class ThesaurusExtractEditForm(DialogEditForm):
     """Thesaurus extract edit form"""
 
@@ -463,12 +460,6 @@ class ThesaurusExtractEditForm(DialogEditForm):
 # Thesaurus merge menus and forms
 #
 
-class ThesaurusMergeMenuItem(JsMenuItem):
-    """Thesaurus content edit menu item"""
-
-    title = _(":: Merge thesaurus...")
-
-
 class IMergeDialogFormButtons(Interface):
     """Export dialog form buttons"""
 
@@ -519,16 +510,17 @@ class ThesaurusMergeEditForm(DialogAddForm):
         pass
 
 
+class ThesaurusMergeMenuItem(DialogMenuItem):
+    """Thesaurus content edit menu item"""
+
+    title = _(":: Merge thesaurus...")
+    target = ThesaurusMergeEditForm
+
+
 #
 # Thesaurus exports menus and forms
 #
 
-class ThesaurusExportMenuItem(JsMenuItem):
-    """Thesaurus export menu item"""
-
-    title = _(":: Export thesaurus...")
-
-
 class IExportDialogFormButtons(Interface):
     """Export dialog form buttons"""
 
@@ -579,3 +571,10 @@ class ThesaurusExportEditForm(DialogAddForm):
 
     def add(self, object):
         pass
+
+
+class ThesaurusExportMenuItem(DialogMenuItem):
+    """Thesaurus export menu item"""
+
+    title = _(":: Export thesaurus...")
+    target = ThesaurusExportEditForm
